@@ -93,7 +93,7 @@ class AnnotationData:
             _chromosome_gff3 = row['seqid']
             _chromosome_vcf = self.metadata_gff3['gff3_to_vcf_chromosome_mapping'][ _chromosome_gff3 ]
             number_of_variants = self.gd.count_variants_in_window(str(_chromosome_vcf), row['start'], row['end'])
-            exons = self.genes.loc[(self.genes['seqid'] == row['seqid']) &(self.genes['start'] >= row['start']) & (self.genes['end'] <= row['end']) & (self.genes['type'] == 'exon')]
+            exons = self.genes.loc[(self.genes['seqid'] == row['seqid']) & (self.genes['start'] >= row['start']) & (self.genes['end'] <= row['end']) & (self.genes['type'] == 'exon')]
             number_of_exon_variants = exons.apply(count_exon_variants, axis=1)
             return pd.Series( [number_of_variants, number_of_exon_variants.sum() ], index=['number_of_variants', 'number_of_exon_variants'])
 
@@ -103,7 +103,7 @@ class AnnotationData:
             geneStatsCacheFilename = self.datadir+'____gene_stats_.hdf5'
             try:
                 gene_list = pd.read_hdf(geneStatsCacheFilename, key='s')
-                print("++++ Loaded Pandas Dataframe for gene stats")
+                #print("++++ Loaded Pandas Dataframe for gene stats")
 
                 genes_number_of_variants = gene_list[ ['number_of_variants', 'number_of_exon_variants'] ].copy()
                 merged = pd.concat([genes_with_descriptions, genes_number_of_variants], axis=1)
@@ -117,7 +117,7 @@ class AnnotationData:
                 #genes_number_of_variants = genes_with_descriptions.parallel_apply(count_genic_variants, axis=1, result_type='expand')
                 #genes_with_descriptions = genes_with_descriptions.iloc[0:50]
                 genes_number_of_variants = genes_with_descriptions.apply(count_genic_variants, axis=1, result_type='expand')
-                print("==== genes_with_descriptions.parallel_apply() calculation time: ", timer() - start)
+                #print("==== genes_with_descriptions.parallel_apply() calculation time: ", timer() - start)
                 merged = pd.concat([genes_with_descriptions, genes_number_of_variants], axis=1)
 
                 #gene_list = merged[ ['ID', 'seqid', 'start', 'end', 'primary_confidence_class', 'description', 'number_of_variants', 'number_of_exon_variants'] ].copy()
@@ -128,12 +128,16 @@ class AnnotationData:
             gene_list = genes_with_descriptions
 
 
+        self.genes_with_stats = gene_list
         genes_list = gene_list.to_dict('split')
 
         genes_grouped_by_seqid = genes_only.groupby(self.genes.seqid)
         list_chrom_gff3 = pd.unique(genes_only['seqid']).tolist()
         genes_start_positions = {}
+        #print('+++++++++++++++++++++++++++++++++')
+        #print(list_chrom_gff3)
         for _chr in list_chrom_gff3:
+            #print('+++++++++++ ', _chr)
             _curr_group = genes_grouped_by_seqid.get_group(_chr)
             genes_start_positions[_chr] = pd.DataFrame(_curr_group['start'].drop_duplicates(keep='first'))
             genes_start_positions[_chr].set_index('start', drop=False, inplace=True)
@@ -143,11 +147,13 @@ class AnnotationData:
         self.genes_list_json_dumped = json.dumps({'genes': genes_list})
         self.genes_grouped_by_seqid = genes_grouped_by_seqid
         self.genes_start_positions = genes_start_positions
+        #print(self.genes_start_positions)
 
 
     def get_nearest_gene_start_pos(self, chrom, pos):
         seqid = self.chrom_gff3_map[chrom]
-        nearest = self.genes_start_positions[seqid].index.get_loc(pos, method='nearest')
+        #nearest = self.genes_start_positions[seqid].index.get_loc(pos, method='nearest')
+        nearest = self.genes_start_positions[seqid].index.get_indexer([pos], method='nearest')[0]
         start_pos = int(self.genes_start_positions[seqid].iloc[nearest].start)
         _genes = self.genes_grouped_by_seqid.get_group(seqid)
         return _genes.loc[(_genes['start'] == start_pos)]
